@@ -13,13 +13,16 @@ public:
     MainWindow(QWidget *parent = 0);
     ~MainWindow();
 
-
+public slots:
+    void showHelp();
+    void showAbout();
 protected:
     void changeEvent(QEvent *e);
     void keyPressEvent(QKeyEvent *e);
     void keyReleaseEvent(QKeyEvent *e);
 private slots:
    void locationLineEnterKeyHandler();
+
 private:
     Ui::MainWindow *ui;
 
